@@ -1,15 +1,20 @@
-
 open Ppx_hash_lib.Std
 open Hash.Builtin
 
 module Barbins_example = struct
+  module X = struct
+    type t = int [@@deriving hash]
+  end
 
-  module X = struct type t = int [@@deriving hash] end
-  module Y = struct type y = int [@@deriving hash] end
-  module Z = struct type t = int [@@deriving hash] end
+  module Y = struct
+    type y = int [@@deriving hash]
+  end
+
+  module Z = struct
+    type t = int [@@deriving hash]
+  end
 
   module Example = struct
-
     module T = struct
       type t =
         { x : X.t
@@ -38,15 +43,16 @@ module Barbins_example = struct
         match t.cached with
         | Some x -> x
         | None ->
-          let cached = T.hash t in (* dont use state *)
+          let cached = T.hash t in
+          (* dont use state *)
           t.cached <- Some cached;
           cached
+      ;;
 
-      let hash_fold_t (state:Hash.state) (t : t) =
-        hash_fold_int state (hash t) (* use state *)
+      let hash_fold_t (state : Hash.state) (t : t) = hash_fold_int state (hash t)
 
+      (* use state *)
     end
-
   end
 
   module Client = struct
@@ -54,5 +60,4 @@ module Barbins_example = struct
     type t1 = Example.Unmemoized.t [@@deriving hash]
     type t3 = Example.Memoized.t [@@deriving hash]
   end
-
 end
